// Copyright (c) Jupyter Development Team.
// Distributed under the terms of the Modified BSD License.
"use strict";
var docregistry_1 = require('jupyterlab/lib/docregistry');
var phosphor_disposable_1 = require('phosphor-disposable');
var index_1 = require('./index');
var WIDGET_MIMETYPE = 'application/vnd.jupyter.widget';
/**
 * The widget manager provider.
 */
exports.widgetManagerExtension = {
    id: 'jupyter.extensions.widgetManager',
    requires: [docregistry_1.DocumentRegistry],
    activate: activateWidgetExtension
};
var IPyWidgetExtension = (function () {
    function IPyWidgetExtension() {
    }
    /**
     * Create a new extension object.
     */
    IPyWidgetExtension.prototype.createNew = function (nb, context) {
        var wManager = new index_1.WidgetManager(context, nb.content.rendermime);
        var wRenderer = new index_1.WidgetRenderer(wManager);
        nb.content.rendermime.addRenderer(WIDGET_MIMETYPE, wRenderer, 0);
        return new phosphor_disposable_1.DisposableDelegate(function () {
            if (nb.rendermime) {
                nb.rendermime.removeRenderer(WIDGET_MIMETYPE);
            }
            wRenderer.dispose();
            wManager.dispose();
        });
    };
    return IPyWidgetExtension;
}());
exports.IPyWidgetExtension = IPyWidgetExtension;
/**
 * Activate the widget extension.
 */
function activateWidgetExtension(app, registry) {
    registry.addWidgetExtension('Notebook', new IPyWidgetExtension());
}
